Authors
-------

``attrs`` is written and maintained by `Hynek Schlawack <https://hynek.me/>`_.

The development is kindly supported by `Variomedia AG <https://www.variomedia.de/>`_.

It’s the spiritual successor of `characteristic <https://characteristic.readthedocs.org/>`_ and aspires to fix some of it clunkiness and unfortunate decisions.  Both were inspired by Twisted’s `FancyEqMixin <https://twistedmatrix.com/documents/current/api/twisted.python.util.FancyEqMixin.html>`_ but both are implemented using class decorators because `sub-classing is bad for you <https://www.youtube.com/watch?v=3MNVP9-hglc>`_, m’kay?


The following folks helped forming ``attrs`` into what it is now:

- `Glyph <https://github.com/glyph/>`_
- `HawkOwl <https://github.com/hawkowl>`_
- `Lynn Root <https://github.com/econchick>`_
- `Samuel A. Falvo II <https://github.com/sam-falvo>`_
- `Wouter Bolsterlee <https://github.com/wbolster/>`_
- `Ying Li <https://github.com/cyli>`_

Of course ``characteristic``\ ’s `hall of fame <https://characteristic.readthedocs.org/en/stable/license.html>`_ applies as well since they share a lot of code.
